| Title: | Access the 'Windsor.ai' API |
|---|---|
| Description: | Collect multichannel marketing data from sources such as Google analytics, Facebook Ads, and many others using the 'Windsor.ai' API <https://www.windsor.ai/api-fields/>. |
| Authors: | Novica Nakov [aut, cre], Windsor.ai [cph] |
| Maintainer: | Novica Nakov <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.2 |
| Built: | 2026-05-21 08:34:12 UTC |
| Source: | https://github.com/windsor-ai/windsorair |
A dataset containing sample gooole and facebook ads data fetched from windsor.ai API. See more at: https://www.windsor.ai/api-fields/
my_datamy_data
A data frame with 1677 rows and 6 variables:
name of the campaign
number of clicks
spend data
the type of referals
source of the data (google, facebook, etc.)
googlesheets id
Windsor fetch A function to fetch data from the Windsor.ai API
windsor_fetch( api_key, connector = "all", date_preset = "last_7d", fields = c("source", "campaign", "clicks", "medium", "sessions", "spend") )windsor_fetch( api_key, connector = "all", date_preset = "last_7d", fields = c("source", "campaign", "clicks", "medium", "sessions", "spend") )
api_key |
Your api key to access Windsor.ai API |
connector |
A connector for the data source. The connector "all" connector blends data from all sources See https://www.windsor.ai/api-fields/ for details. |
date_preset |
the period for which data is fetched from the API. See https://www.windsor.ai/api-fields/ for details |
fields |
The fields fetched from the API for a given connector See https://www.windsor.ai/api-fields/ for details. |
A data frame containing the desired data.
## Not run: windsor_fetch <- (api_key = "your api key", connector = "all", date_preset = "last_7d", fields = c("source", "campaign", "clicks", "medium", "sessions", "spend")) ## End(Not run)## Not run: windsor_fetch <- (api_key = "your api key", connector = "all", date_preset = "last_7d", fields = c("source", "campaign", "clicks", "medium", "sessions", "spend")) ## End(Not run)